@@ -32,13 +32,13 @@ define(function(){
     // expose modules
     
     jprop('utils','base/js/utils')
-    
+    jprop('mathjaxutils','base/js/mathjaxutils');
+
     //Jupyter.load_extensions = Jupyter.utils.load_extensions;
     // 
     jprop('security','base/js/security');
     jprop('keyboard','base/js/keyboard');
     jprop('dialog','base/js/dialog');
-    jprop('mathjaxutils','notebook/js/mathjaxutils');
 
 
     //// exposed constructors
@@ -73,7 +73,7 @@ define(function(){
     // tree
     jglobal('SessionList','tree/js/sessionlist');
 
-    Jupyter.version = "6.1.3";
+    Jupyter.version = "6.4.6";
     Jupyter._target = '_blank';
 
     return Jupyter;
