@@ -10,7 +10,7 @@ define([
 
     var CellToolbar = celltoolbar.CellToolbar;
 
-    var raw_edit = function (cell) {
+    var raw_edit = function (cell , edit_metadata_button) {
         dialog.edit_metadata({
             md: cell.metadata,
             callback: function (md) {
@@ -18,7 +18,8 @@ define([
             },
             name: i18n.msg._('Cell'),
             notebook: this.notebook,
-            keyboard_manager: this.keyboard_manager
+            keyboard_manager: this.keyboard_manager,
+            edit_metadata_button: edit_metadata_button
         });
     };
 
@@ -28,9 +29,10 @@ define([
             .addClass("btn btn-default btn-xs")
             .text(i18n.msg._("Edit Metadata"))
             .click( function () {
-                raw_edit(cell);
+                raw_edit(cell, this);
                 return false;
             });
+
         button_container.append(button);
     };
 
